@@ -1,4 +1,3 @@
-/* -*- Mode: csharp; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 //
 // FilterPPT.cs
 //
@@ -372,7 +371,7 @@ internal class RecordType
 
 namespace Beagle.Filters {
     
-	public class FilterPPT : Beagle.Daemon.Filter {
+	public class FilterPPT : FilterOle {
 
 		private enum TextType {
 			Invalid = -1,
@@ -387,9 +386,7 @@ namespace Beagle.Filters {
 			QuarterBody
 		};
 
-		Infile file;
 		TextType textType;
-		string FileName;
 		public FilterPPT () 
 		{
 			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("application/vnd.ms-powerpoint"));
@@ -401,9 +398,15 @@ namespace Beagle.Filters {
 
 		private int ParseElement (Input stream)
 		{
-			byte [] data = stream.Read(8);
-			if (data == null)
+			int data_remaining = (int) stream.Remaining;
+			//Console.WriteLine ("stream.Remaining = {0}", data_remaining);
+
+			// Weird!! Well, Its a M$ format ;-)
+			// Fixes: 323312
+			byte [] data = stream.Read (data_remaining > 7 ? 8 : data_remaining);
+			if (data == null || data_remaining < 8)
 				return 0;
+
 			RecordType.TypeCode opcode = (RecordType.TypeCode) GetInt16(data, 2);
 			int length = GetInt32(data, 4);
 			RecordType type = RecordType.Find (opcode);
@@ -422,6 +425,8 @@ namespace Beagle.Filters {
 						if (elem_length == 0)
 							return 0;
 						length_remaining -= elem_length;
+						//Console.WriteLine ("ParseElement: length = {0}, rem = {1}", 
+						//		   elem_length, length_remaining);
 					}
 				}
 			} else {
@@ -459,6 +464,7 @@ namespace Beagle.Filters {
 							HotDown ();
 						else
 							AppendStructuralBreak ();
+						//Console.WriteLine ("Text : {0}", strData);
 					}  else if (opcode == RecordType.TypeCode.TextHeaderAtom) {
 						data = stream.Read (4);
 						textType = (TextType) GetInt32 (data, 0);
@@ -475,106 +481,17 @@ namespace Beagle.Filters {
 		}
 		
 
-		private void ExtractMetaData (Input sumStream, Input docSumStream)
+		override protected void ExtractMetaData (Input sumStream, Input docSumStream)
 		{
-			DocMetaData sumMeta = null;
-			if (sumStream != null)
-				sumMeta = Msole.MetadataReadReal (sumStream);
-			else
-				Logger.Log.Error ("SummaryInformationStream not found in {0}", FileName);
-
-			DocMetaData docSumMeta = null;
-			if (docSumStream != null)
-				docSumMeta = Msole.MetadataReadReal (docSumStream);
-			else
-				Logger.Log.Error ("DocumentSummaryInformationStream not found in {0}", FileName);
-
+			int slide_count = 0;
 			DocProp prop = null;
-			string str = null;
-			if (sumMeta != null) {
-				prop = sumMeta.GetProp ("dc:title");
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("dc:title", str));
 
-				str = null;
-				prop = sumMeta.GetProp ("dc:subject");			
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);			
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("dc:subject", str));
-
-				str = null;
-				prop = sumMeta.GetProp ("dc:description");		
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);			
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("dc:description", str));
-
-				str = null;
-				prop = sumMeta.GetProp ("gsf:keywords");
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("fixme:keywords", str));
-
-				str = null;
-				prop = sumMeta.GetProp ("gsf:creator");
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("fixme:author", str));
-			}
-			
 			if (docSumMeta != null) {
-				str = null;
-				prop = docSumMeta.GetProp ("gsf:company");
+				prop = docSumMeta.Lookup ("gsf:slide-count");
 				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("fixme:company", str));
-
-				str = null;
-				prop = docSumMeta.GetProp ("gsf:slide-count");
-				if (prop != null)
-					str = Gsf.Global.GetPropValStr (prop);
-				if (str != null && str.Length > 0)
-					AddProperty (Beagle.Property.New ("fixme:slide-count", str));
-			}
-		}
-		override protected void DoPullProperties ()
-		{
-			Input sumStream = null;
-			Input docSumStream = null;
-			string str = null;
-			int childCount = 0;
-			int found = 0;
-			
-			if (file == null) {
-				Finished ();
-				return;
-			}
-			
-			try {
-				// FIXME: Should try to use Encoding instead of 
-				// string.IndexOf ()... Hacky stuff ;-)
-				childCount = file.NumChildren();
-				for (int i = 0; i < childCount && found != 2; i++) {
-					str = file.NameByIndex (i);	
-					if (str.IndexOf ("SummaryInformation") > -1 && found < 1) {
-						sumStream = file.ChildByIndex (i);
-						found = 1;
-					}
-					else if (str.IndexOf ("DocumentSummaryInformation") > -1) {
-						docSumStream = file.ChildByIndex (i);
-						found = 2;
-					}
-				}
-				ExtractMetaData (sumStream, docSumStream);
-			} catch (Exception e) {
-				Logger.Log.Error ("Exception {0} occurred duing DoPullProperties.", e.Message);
-				Finished ();
+					slide_count = (int) prop.Val;
+				if (slide_count > 0)
+					AddProperty (Beagle.Property.NewUnsearched ("fixme:slide-count", slide_count));
 			}
 		}
 
@@ -600,71 +517,67 @@ namespace Beagle.Filters {
 					// after "Document" container.
 					// And certain PPTs do have some slides in after
 					// "Document" container.
-					while (!stream.Eof)
-						ParseElement (stream);
+					//Console.WriteLine ("Length of stream = {0}", stream.Size);
+					int ret = -1;
+					while (!stream.Eof && ret != 0) {
+						ret = ParseElement (stream);
+						//Console.WriteLine ("Position of the ptr in the stream: {0}", stream.Position);
+					}
+					
+					stream.Dispose ();
 				} else {
 					Logger.Log.Error ("Ole stream not found in {0}.  Content extraction skipped.", FileName);
 				}
-			Finished();
+
+				Finished ();
 			} catch (Exception e) {
 				Logger.Log.Error ("Exception {0} occurred during DoPull.", e.Message);
-				Finished ();
+				Error ();
 			}
 		}
 
-		override protected void DoOpen (FileInfo info)
+		override protected void OpenStorage (FileInfo info)
 		{
 			FileName = info.FullName;
 
-			try {
-				Gsf.Global.Init ();
-				Input input = Input.MmapNew (info.FullName);
-				if (input != null) {
-					input = input.Uncompress();
-					file = new InfileMSOle (input);
-				}
-				if (input == null || file == null) {
-					Logger.Log.Error ("Unable to open [{0}] ",info.FullName);
-					Finished ();
-					return;
-				}
-				
-			} catch (Exception e) {
-				Logger.Log.Error ("Unable to open "+info.FullName);
-				Finished ();
-				return;
-			}
-			
 			// PPT 95/97-2000 format contains a "PP97_DUALSTORAGE", which is required
 			// to index PPT 97-2000 files.
 			// We don't support PPT 95 files, however, we happily accept patches ;-)
-
-			Input dualStorTemp = null;
+			
+			Input temp_input = null;
 			try {
-				if ((dualStorTemp = file.ChildByName ("PP97_DUALSTORAGE")) != null) {
+				temp_input = file.ChildByName ("PP97_DUALSTORAGE");
+				
+				if (temp_input != null) {
 					// "PP97_DUALSTORAGE" is a storage containing some streams
-					if (dualStorTemp.Handle != IntPtr.Zero)
-						file = (Gsf.Infile) GLib.Object.GetObject (dualStorTemp.Handle);
-				} else if (((dualStorTemp = file.ChildByName ("Header")) != null) ||
-					   ((dualStorTemp = file.ChildByName ("PowerPoint Document")) == null)) {
-					Logger.Log.Error ("{0} is a PPT 95/4.0 file.  Beagle does not support PPT 95 files. Skipping...", FileName);
-					Finished ();
+					if (temp_input.Handle != IntPtr.Zero) {
+						file.Dispose ();
+						file = (Gsf.Infile) GLib.Object.GetObject (temp_input.Handle);
+					}
+				} else {
+					using (temp_input = file.ChildByName ("Header")) {
+						using (Input temp_input2 = file.ChildByName ("PowerPoint Document")) {
+							if (temp_input != null || temp_input2 == null) {
+								Log.Error ("{0} is an unsupported PPT 95/4.0 file.  Skipping", FileName);
+								Error ();
+								return;
+							}
+						}
+					}
+				}	
+				
+				using (temp_input = file.ChildByName ("EncryptedSummary")) {
+					if (temp_input != null) {
+						Log.Warn ("{0} is a password-protected PowerPoint file.  Skipping.", FileName);
+						Error ();
+					}
 				}
+
 			} catch (Exception e) {
 				
 				Logger.Log.Error ("Unable to open OleFile stream of "+info.FullName);
-				Finished ();
+				Error ();
 			}
 		}
-
-		// FIXME: These are utility functions and can be useful 
-		// outside this filter as well.
-		public static int GetInt32 (byte [] data, int offset) {
-			return data[offset] + (data[offset + 1] << 8) + (data[offset + 2] << 16) + (data[offset + 3] << 24);
-		}
-		public static int GetInt16 (byte [] data, int offset) {
-			return data[offset] + (data[offset + 1] << 8);
-		}
-
 	}
 }
