@@ -57,7 +57,9 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		// 3: Switched to UTC for all times, changed the properties a bit.
 		// 4: Changed the key of TextFilenamePropKey to beagle:Filename - it might be useful in clients.
 		//    Make SplitFilenamePropKey unstored
-		const int MINOR_VERSION = 4;
+		// 5: Keyword properies in the private namespace are no longer lower cased; this is required to
+		//    offset the change in LuceneCommon.cs
+		const int MINOR_VERSION = 5;
 
 		private object big_lock = new object ();
 
@@ -436,6 +438,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			if (filter.Ignore (parent, name, true))
 				return;
 
+			// FIXME: ! parent.HasChildWithName (name)
 			if (parent != null && parent.HasChildWithName (name))
 				return;
 
@@ -915,8 +918,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			try {
 				Mono.Unix.Native.Syscall.stat (path, out stat);
 			} catch (Exception ex) {
-				Logger.Log.Debug ("Caught exception stat-ing {0}", path);
-				Logger.Log.Debug (ex);
+				Logger.Log.Debug (ex, "Caught exception stat-ing {0}", path);
 				return RequiredAction.None;
 			}
 
@@ -1288,7 +1290,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			// Store the hit's internal uri in a property
 			Property prop;
 			prop = Property.NewUnsearched ("beagle:InternalUri",
-						    UriFu.UriToSerializableString (hit.Uri));
+						       UriFu.UriToEscapedString (hit.Uri));
 			hit.AddProperty (prop);
 
 			// Now assemble the path by looking at the parent and name
@@ -1381,20 +1383,18 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		{
 			// Uri remapping from a hit is easy: the internal uri
 			// is stored in a property.
-			Uri uri;
-			uri = UriFu.UriStringToUri (hit ["beagle:InternalUri"]);
+			Uri uri = UriFu.EscapedStringToUri (hit ["beagle:InternalUri"]);
 
-			string path;
-			path = TextCache.UserCache.LookupPathRaw (uri);
+			string path = TextCache.UserCache.LookupPathRaw (uri);
 
 			if (path == null)
 				return null;
 
 			// If this is self-cached, use the remapped Uri
 			if (path == TextCache.SELF_CACHE_TAG)
-				path = hit.Uri.LocalPath;
+				return SnippetFu.GetSnippetFromFile (query_terms, hit.Uri.LocalPath);
 
-			return SnippetFu.GetSnippetFromFile (query_terms, path);
+			return SnippetFu.GetSnippetFromTextCache (query_terms, path);
 		}
 
 		override public void Start ()
